@@ -1,3 +1,5 @@
+//! Mouse button, location and delta support for EZInput.
+
 use std::hash::Hash;
 
 use crate::prelude::*;
@@ -9,6 +11,7 @@ use bevy::{
 };
 use serde::{Deserialize, Serialize};
 
+/// All types of axis that can be moved in a mouse.
 #[derive(
     PartialEq, Eq, Hash, Clone, Copy, Debug, Deserialize, Serialize, strum_macros::Display,
 )]
@@ -18,6 +21,7 @@ pub enum MouseAxisType {
     Wheel,
 }
 
+/// Mouse button, location and delta support for EZInput.
 #[derive(PartialEq, Debug, Component, Clone, Default)]
 pub struct EZInputMouseService {
     pub mouse_position: Option<Vec2>,
@@ -27,6 +31,7 @@ pub struct EZInputMouseService {
 }
 
 impl EZInputMouseService {
+    /// Change the current mouse location and delta and set the last input source to Mouse.
     pub fn set_mouse_location<Keys>(
         &mut self,
         view: &mut InputView<Keys>,
@@ -35,25 +40,29 @@ impl EZInputMouseService {
     ) where
         Keys: BindingTypeView,
     {
+        let state = PressState::Pressed {
+            started_pressing_instant: None,
+        };
+
         view.set_axis_value(
             BindingInputReceiver::MouseAxis(MouseAxisType::X),
             position.x,
-            PressState::Pressed,
+            state,
         );
         view.set_axis_value(
             BindingInputReceiver::MouseAxis(MouseAxisType::Y),
             position.y,
-            PressState::Pressed,
+            state,
         );
         view.set_axis_value(
             BindingInputReceiver::MouseAxisDelta(MouseAxisType::X),
             delta.x,
-            PressState::Pressed,
+            state,
         );
         view.set_axis_value(
             BindingInputReceiver::MouseAxisDelta(MouseAxisType::Y),
             delta.y,
-            PressState::Pressed,
+            state,
         );
 
         self.mouse_delta = Some(delta);
@@ -62,6 +71,7 @@ impl EZInputMouseService {
         view.last_input_source = Some(InputSource::Mouse);
     }
 
+    /// Tick the mouse by stop moving the axis when released.
     pub fn tick_mouse<Keys>(&mut self, view: &mut InputView<Keys>)
     where
         Keys: BindingTypeView,
@@ -91,6 +101,7 @@ impl EZInputMouseService {
         self.mouse_delta = None;
     }
 
+    /// Set the mouse button state for the given button and set the last input source to Mouse.
     pub fn set_mouse_button_state<Keys>(
         &mut self,
         view: &mut InputView<Keys>,
@@ -104,7 +115,9 @@ impl EZInputMouseService {
         view.set_axis_value(
             BindingInputReceiver::MouseButton(button),
             match state {
-                PressState::Pressed | PressState::JustPressed => view.get_receiver_default_axis_value(BindingInputReceiver::MouseButton(button)),
+                PressState::Pressed {..} => {
+                    view.get_receiver_default_axis_value(BindingInputReceiver::MouseButton(button))
+                }
                 PressState::Released => 0.,
             },
             state,
@@ -112,6 +125,7 @@ impl EZInputMouseService {
     }
 }
 
+/// Input system responsible for handling mouse input and setting the button state for each updated button and axis.
 pub(crate) fn mouse_input_system<Keys>(
     mut query: Query<(&mut InputView<Keys>, &mut EZInputMouseService)>,
     mut cursor_rd: EventReader<CursorMoved>,
