@@ -1,11 +1,12 @@
+//! An public import for each module available for use.
+
 pub use crate::binding::*;
 pub use crate::bundle::*;
-pub use crate::common::*;
 pub use crate::gamepad::*;
 pub use crate::keyboard::*;
 pub use crate::mouse::*;
 pub use crate::plugin::*;
 pub use crate::view::*;
 pub use crate::labels::*;
-pub use crate::state::*;
+pub use crate::press_state::*;
 pub(crate) use crate::tick::*;
\ No newline at end of file
