@@ -1,9 +1,12 @@
+//! A view is a object where all input states are stored. It also has useful methods such checking
+//! if a key or axis for a [`BindingTypeView`] is pressed or released by proving the [`PressState`].
 use std::collections::HashMap;
 
 use bevy::prelude::Component;
 
 use crate::prelude::*;
 
+/// The currently accepted input sources for bindings and receivers.
 #[derive(PartialEq, Eq, Hash, Clone, Copy, Debug, strum_macros::Display)]
 pub enum InputSource {
     Gamepad,
@@ -11,9 +14,12 @@ pub enum InputSource {
     Mouse,
 }
 
+/// The current axis state. In other words, the strength (how much the axis is moved) and press state.
 #[derive(PartialEq, Clone, Copy, Debug)]
 pub struct AxisState(pub f32, pub PressState);
 
+/// A view is a object where all input states are stored. It also has useful methods such checking
+/// if a key or axis for a [`BindingTypeView`] is pressed or released by proving the [`PressState`].
 #[derive(PartialEq, Clone, Debug, Component, Default)]
 pub struct InputView<Keys>
 where
@@ -30,6 +36,7 @@ impl<Keys> InputView<Keys>
 where
     Keys: BindingTypeView,
 {
+    /// Create an empty input view.
     pub fn empty() -> Self {
         Self {
             last_input_source: None,
@@ -40,11 +47,13 @@ where
         }
     }
 
+    /// Insert a new binding into the storage.
     pub fn add_binding(&mut self, key: Keys, binding: &ActionBinding<Keys>) -> &mut Self {
         self.bindings.insert(key, binding.clone());
         self
     }
 
+    /// Add a default axis value to a receiver.
     pub fn add_receiver_default_axis_values(
         &mut self,
         receiver: BindingInputReceiver,
@@ -54,14 +63,20 @@ where
         self
     }
 
+    /// Returns the default axis value for a receiver, or `1` if not found.
     pub fn get_receiver_default_axis_value(&self, receiver: BindingInputReceiver) -> f32 {
-        self.receiver_default_axis_values.get(&receiver).unwrap_or(&1.).clone()
+        self.receiver_default_axis_values
+            .get(&receiver)
+            .unwrap_or(&1.)
+            .clone()
     }
 
+    /// Set the button state for a specific key receiver.
     pub fn set_key_receiver_state(&mut self, key: BindingInputReceiver, state: PressState) {
         self.key_receiver_states.insert(key, state);
     }
 
+    /// Set the axis state for a specific axis receiver.
     pub fn set_axis_value(
         &mut self,
         receiver: BindingInputReceiver,
@@ -72,24 +87,35 @@ where
             .insert(receiver, AxisState(value, element_state));
     }
 
-    pub fn is_key_active(&self, kind: &Keys) -> bool {
+    /// Return the current press state for a specific binding matching with the given BindingTypeView.
+    pub fn key(&self, kind: &Keys) -> PressState {
         let binding = self.bindings.get(kind);
         if let Some(binding) = binding {
-            binding.input_receivers.iter().any(|r| {
-                r.iter()
-                    .all(|b| self.key_receiver_states.get(b).unwrap_or(&PressState::Released) != &PressState::Released)
-            })
-        } else {
-            false
+            for r in binding.input_receivers.iter() {
+                let mut states = r.0.iter().map(|x| {
+                    self.key_receiver_states
+                        .get(x)
+                        .unwrap_or(&PressState::Released)
+                });
+                if states.len() < 1 && !states.all(|x| match x {
+                    &PressState::Released => false,
+                    _ => true
+                }) {
+                    continue;
+                }
+                return states.min().unwrap_or(&PressState::Released).clone();
+            }
         }
+        PressState::Released
     }
 
-    pub fn get_axis_states(&self, kind: &Keys) -> Vec<&AxisState> {
+    /// Return the current axis state for a specific binding matching with the given BindingTypeView.
+    pub fn axis(&self, kind: &Keys) -> Vec<&AxisState> {
         let binding = self.bindings.get(kind);
         if let Some(binding) = binding {
             let mut vec = Vec::new();
             for r in binding.input_receivers.iter() {
-                for r in r.iter() {
+                for r in r.0.iter() {
                     vec.push(
                         self.axis_receiver_states
                             .get(r)
